%bcond_with bootstrap

Name:           apache-commons-compress
Version:        1.21
Release:        %mkrel 1
Group:          Development/Java
Summary:        Java API for working with compressed files and archivers
License:        ASL 2.0
URL:            https://commons.apache.org/proper/commons-compress/
BuildArch:      noarch

Source0:        https://archive.apache.org/dist/commons/compress/source/commons-compress-%{version}-src.tar.gz

Patch0:         0001-Remove-Brotli-compressor.patch
Patch1:         0002-Remove-ZSTD-compressor.patch
Patch2:         0003-Remove-Pack200-compressor.patch

BuildRequires:  maven-local
%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.commons:commons-parent:pom:)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.hamcrest:hamcrest)
BuildRequires:  mvn(org.mockito:mockito-core)
BuildRequires:  mvn(org.osgi:org.osgi.core)
BuildRequires:  mvn(org.tukaani:xz)
%endif

%description
The Apache Commons Compress library defines an API for working with
ar, cpio, Unix dump, tar, zip, gzip, XZ, Pack200 and bzip2 files.
In version 1.14 read-only support for Brotli decompression has been added,
but it has been removed form this package.

%package javadoc
Summary:        API documentation for %{name}

%description javadoc
This package provides %{summary}.

%prep
%setup -q -n commons-compress-%{version}-src

# Unavailable Google Brotli library (org.brotli.dec)
%patch0 -p1
%pom_remove_dep org.brotli:dec
rm -r src/{main,test}/java/org/apache/commons/compress/compressors/brotli

# Unavailable ZSTD JNI library
%patch1 -p1
%pom_remove_dep :zstd-jni
rm -r src/{main,test}/java/org/apache/commons/compress/compressors/zstandard
rm src/test/java/org/apache/commons/compress/compressors/DetectCompressorTestCase.java

# Remove support for pack200 which depends on ancient asm:asm:3.2
%patch2 -p1
%pom_remove_dep asm:asm
rm -r src/{main,test}/java/org/apache/commons/compress/harmony
rm -r src/main/java/org/apache/commons/compress/compressors/pack200
rm src/main/java/org/apache/commons/compress/java/util/jar/Pack200.java
rm src/test/java/org/apache/commons/compress/compressors/Pack200TestCase.java
rm -r src/test/java/org/apache/commons/compress/compressors/pack200
rm src/test/java/org/apache/commons/compress/java/util/jar/Pack200Test.java

# remove osgi tests, we don't have deps for them
%pom_remove_dep org.ops4j.pax.exam:::test
%pom_remove_dep :org.apache.felix.framework::test
%pom_remove_dep :javax.inject::test
%pom_remove_dep :slf4j-api::test
rm src/test/java/org/apache/commons/compress/OsgiITest.java

# Not packaged
%pom_remove_dep com.github.marschall:memoryfilesystem
rm src/test/java/org/apache/commons/compress/archivers/tar/TarMemoryFileSystemTest.java

%build
%mvn_file  : commons-compress %{name}
%mvn_alias : commons:
%mvn_build -- -Dcommons.osgi.symbolicName=org.apache.commons.compress

%install
%mvn_install

%files -f .mfiles
%doc LICENSE.txt NOTICE.txt

%files javadoc -f .mfiles-javadoc
%doc LICENSE.txt NOTICE.txt



%changelog
* Tue Dec 14 2021 neoclust <neoclust> 1.21-1.mga8
+ Revision: 1762041
- New version 1.21: Fixes CVE-2021-3551[5-7] and CVE-2021-36090 (mga#29254)

* Fri Sep 04 2020 daviddavid <daviddavid> 1.20-1.mga8
+ Revision: 1621508
- Update to version 1.20
- Rebuilt for JDK-11
- Ensure Java 8 level bytecode when built on Java 11

* Sun Feb 16 2020 umeabot <umeabot> 1.19-2.mga8
+ Revision: 1536168
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 1.19-1.mga8
+ Revision: 1453580
- Update to version 1.19

* Tue Oct 15 2019 daviddavid <daviddavid> 1.18-3.mga8
+ Revision: 1453426
- Migrate from the obsolete felix-osgi-core to osgi-core

* Sat Aug 24 2019 daviddavid <daviddavid> 1.18-2.mga8
+ Revision: 1431674
- Remove build-dependency on powermock

* Thu Jul 18 2019 daviddavid <daviddavid> 1.18-1.mga8
+ Revision: 1422296
- Update to upstream version 1.18
- Resolves: CVE-2018-11771
- Fix test suite build against Mockito 2.x
- Rebuild to regenerate OSGi metadata

* Tue Jan 01 2019 luigiwalser <luigiwalser> 1.17-2.mga7
+ Revision: 1347901
- add patch from fedora to fix CVE-2018-11771

* Thu Sep 20 2018 daviddavid <daviddavid> 1.17-1.mga7
+ Revision: 1288212
- Update to upstream version 1.17 (sync with fc29)
- Update to upstream version 1.16.1 (sync with fc28)
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Sun May 14 2017 neoclust <neoclust> 1.12-1.mga6
+ Revision: 1101223
- New version 1.12

* Sun Oct 30 2016 daviddavid <daviddavid> 1.10-1.2.svn1684406.4.mga6
+ Revision: 1064181
- Prevent "SNAPSHOT" from breaking the OSGi metadata

* Wed Mar 02 2016 neoclust <neoclust> 1.10-1.2.svn1684406.3.mga6
+ Revision: 981935
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 1.10-1.2.svn1684406.2.mga6
+ Revision: 975427
- First rebuild of the java stack
- sync package apache-commons-compress with fedora

* Sat Dec 19 2015 zezinho <zezinho> 1.10-1.mga6
+ Revision: 912245
- new version

* Sat Oct 24 2015 daviddavid <daviddavid> 1.8.1-6.mga6
+ Revision: 894865
- disable failed test

* Thu Dec 25 2014 pterjan <pterjan> 1.8.1-5.mga5
+ Revision: 805576
- Clean rebuild
+ dmorgan <dmorgan>
- Restore from Obsolete
+ sander85 <sander85>
- Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 1.8.1-3.mga5
+ Revision: 738971
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.8.1-2.mga5
+ Revision: 677795
- Mageia 5 Mass Rebuild

* Wed Sep 03 2014 dmorgan <dmorgan> 1.8.1-1.mga5
+ Revision: 671672
- New version

* Sun Jun 15 2014 dmorgan <dmorgan> 1.6-1.mga5
+ Revision: 636415
- New version

* Tue Oct 22 2013 umeabot <umeabot> 1.5-4.mga4
+ Revision: 545590
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 dmorgan <dmorgan> 1.5-3.mga4
+ Revision: 501432
- Fix buildrequires

* Fri Sep 20 2013 dmorgan <dmorgan> 1.5-2.mga4
+ Revision: 482643
- Rebuild against new javapackages

* Wed Sep 18 2013 dmorgan <dmorgan> 1.5-1.mga4
+ Revision: 481120
- New upstream version 1.5

* Thu Jul 11 2013 dmorgan <dmorgan> 1.4.1-3.mga4
+ Revision: 453063
- Build with xmvn

* Fri Jan 11 2013 umeabot <umeabot> 1.4.1-2.mga3
+ Revision: 345670
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jun 08 2012 dmorgan <dmorgan> 1.4.1-1.mga3
+ Revision: 257731
- Updated to 1.4.1
- Fixes CVE-2012-2098 Low: Denial of Service

* Fri Jan 06 2012 dmorgan <dmorgan> 1.3-2.mga2
+ Revision: 192146
- Fix file list

* Fri Dec 09 2011 dmorgan <dmorgan> 1.3-1.mga2
+ Revision: 179558
- New version 1.3

* Tue Sep 06 2011 tv <tv> 1.2-1.mga2
+ Revision: 139173
- new release

* Wed Apr 27 2011 dmorgan <dmorgan> 1.1-2.mga1
+ Revision: 92226
- Rebuild after bootstrapping
- imported package apache-commons-compress


* Sat Apr 16 2011 Chris Spike <spike@fedoraproject.org> 1.1-1
- Updated to 1.1
- Adapted to current java packaging guidelines

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Jul 11 2010 Sandro Mathys <red at fedoraproject.org> - 1.0-8
- Fixed the Maven depmap line by replacing org.apache.maven by org.apache.commons

* Mon May 31 2010 Sandro Mathys <red at fedoraproject.org> - 1.0-7
- Fixed regression with missing Provides/Obsoletes for javadocs
- Fixed changelog format

* Sun May 23 2010 Sandro Mathys <red at fedoraproject.org> - 1.0-6
- Fixed Maven depmap to use commons-compress

* Thu May 13 2010 Sandro Mathys <red at fedoraproject.org> - 1.0-5
- Added missing Provides/Obsoletes for javadocs 

* Mon May 10 2010 Sandro Mathys <red at fedoraproject.org> - 1.0-4
- Cleared some problems after the review

* Thu May 06 2010 Sandro Mathys <red at fedoraproject.org> - 1.0-3
- Now using maven2 (mvn-jpp) instead of directly calling javac & co

* Tue May 04 2010 Sandro Mathys <red at fedoraproject.org> - 1.0-2
- Renamed from jakarta-commons-compress
